@@ -163,8 +163,8 @@ def new(config, type, input, depth, feature, max_texture, no_download, no_wait,
     TYPE is the type of input used to create the didimo. Accepted values are:
 
     \b
-        - photo (input must be a .jpg/.jpeg)        
-        - depth (input must be a .png)       
+        - photo (input must be a .jpg/.jpeg/.png)
+        - depth (input must be a .png)
 
         For more information on the input types, visit
         https://docs.didimo.co/api/?javascript#new\b
@@ -174,7 +174,7 @@ def new(config, type, input, depth, feature, max_texture, no_download, no_wait,
     \b
     Examples:
         Create a didimo from a photo
-        $ didimo new photo ~/Downloads/leo.jpg
+        $ didimo new photo /path/input.jpg
 
     """
 
@@ -192,6 +192,9 @@ def new(config, type, input, depth, feature, max_texture, no_download, no_wait,
 
     if len(package_type) > 0:
         payload["transfer_formats"] = package_type
+        package_type = package_type[0]
+    else:
+        package_type = "gltf"
 
     if max_texture != None:
         payload["max_texture_dimension"] = max_texture
@@ -223,7 +226,7 @@ def new(config, type, input, depth, feature, max_texture, no_download, no_wait,
                 time.sleep(2)
         if not no_download:
             if output == None:
-                output = "%s.zip" % didimo_id
+                output = "%s_%s.zip" % (didimo_id, package_type)
             download_didimo(config, didimo_id, "", output)
 
 
@@ -329,7 +332,7 @@ def download(config, id, output, package_type):
         id = sys.stdin.readlines()[0].rstrip()
 
     if output is None:
-        output = "%s.zip" % id
+        output = "%s_%s.zip" % (id, package_type)
     download_didimo(config, id, package_type, output)
 
 
